@@ -241,7 +241,7 @@ class ZhuDb(object):
         kvlist = []
         for key in keydict:
             val = keydict[key]
-            kvlist.append("'{k}'='{v}'".format(k=key, v=val))
+            kvlist.append("{k}='{v}'".format(k=key, v=val))
         if len(kvlist) > 1:
             kvstr = ' AND '.join(kvlist)
         else:
